###################################################
### chunk number 1: 
###################################################
options(width=60)


###################################################
### chunk number 2: 
###################################################
library(twang)


###################################################
### chunk number 3: 
###################################################
data(lalonde)


###################################################
### chunk number 4: psfig
###################################################
par(mfrow=c(1,2))
ps.lalonde <- ps(treat ~ age + educ + black + hispan + nodegree +
                         married + re74 + re75,
                 data = lalonde,
                 plots="optimize",
                 stop.method=stop.methods[c("es.stat.mean","ks.stat.max")],
                 n.trees=2000,
                 interaction.depth=2,
                 shrinkage=0.01,
                 perm.test.iters=0,
                 verbose=FALSE)


###################################################
### chunk number 5: 
###################################################
par(mfrow=c(1,2))
ps.lalonde <- ps(treat ~ age + educ + black + hispan + nodegree +
                         married + re74 + re75,
                 data = lalonde,
                 plots="optimize",
                 stop.method=stop.methods[c("es.stat.mean","ks.stat.max")],
                 n.trees=2000,
                 interaction.depth=2,
                 shrinkage=0.01,
                 perm.test.iters=0,
                 verbose=FALSE)


###################################################
### chunk number 6: 
###################################################
par(mfrow=c(1,1))


###################################################
### chunk number 7: 
###################################################
summary(ps.lalonde$gbm.obj,
        n.trees=ps.lalonde$desc$ks.stat.max$n.trees,
        plot=FALSE)


###################################################
### chunk number 8: 
###################################################
summary(ps.lalonde$gbm.obj,
        n.trees=ps.lalonde$desc$ks.stat.max$n.trees)


###################################################
### chunk number 9: 
###################################################
options(width=85)


###################################################
### chunk number 10: 
###################################################
lalonde.balance <- bal.table(ps.lalonde)
lalonde.balance


###################################################
### chunk number 11: 
###################################################
options(width=60)


###################################################
### chunk number 12: 
###################################################
library(xtable)
pretty.tab <- lalonde.balance$ks.stat.max[,c("tx.mn","ct.mn","ks")]
pretty.tab <- cbind(pretty.tab, lalonde.balance$unw[,"ct.mn"])
names(pretty.tab) <- c("E(Y1|t=1)","E(Y0|t=1)","KS","E(Y0|t=0)")
xtable(pretty.tab,
       caption = "Balance of the treatment and comparison groups",
       label = "tab:balance",
       digits = c(0, 2, 2, 2, 2),
       align=c("l","r","r","r","r"))


###################################################
### chunk number 13: 
###################################################
summary(ps.lalonde)


###################################################
### chunk number 14: 
###################################################
par(mfrow=c(1,2))
plot(ps.lalonde, plots="ps boxplot")
par(mfrow=c(1,1))


###################################################
### chunk number 15: 
###################################################
par(mfrow=c(1,2))
plot(ps.lalonde, plots="t pvalues")
par(mfrow=c(1,1))


###################################################
### chunk number 16: 
###################################################
par(mfrow=c(1,2))
plot(ps.lalonde, plots="es")
par(mfrow=c(1,1))


###################################################
### chunk number 17: 
###################################################
library(survey)


###################################################
### chunk number 18: 
###################################################
lalonde$w <- get.weights(ps.lalonde, type="ATT",stop.method="ks.stat.max")
design.ps <- svydesign(ids=~1, weights=~w, data=lalonde)


###################################################
### chunk number 19: 
###################################################
glm1 <- svyglm(re78 ~ treat, design=design.ps)
summary(glm1)


###################################################
### chunk number 20: 
###################################################
glm2 <- svyglm(re78 ~ treat + nodegree, design=design.ps)
summary(glm2)


###################################################
### chunk number 21: 
###################################################
glm3 <- svyglm(re78 ~ treat + age + educ + black + hispan + nodegree +
                      married + re74 + re75,
               design=design.ps)
summary(glm3)


###################################################
### chunk number 22: 
###################################################
glm4 <- lm(re78 ~ treat + age + educ + black + hispan + nodegree +
                  married + re74 + re75,
           data=lalonde)
summary(glm4)


###################################################
### chunk number 23: 
###################################################
glm5 <- lm(sqrt(re78) ~ treat + age + educ + black + hispan + nodegree +
                        married + sqrt(re74) + sqrt(re75),
           data=lalonde)


###################################################
### chunk number 24: 
###################################################
ps.logit <- glm(treat ~ age + educ + black + hispan + nodegree +
                        married + re74 + re75,
                data = lalonde,
                family = binomial)
lalonde$w.logit <- rep(1,nrow(lalonde))
lalonde$w.logit[lalonde$treat==0] <- exp(predict(ps.logit,subset(lalonde,treat==0)))


###################################################
### chunk number 25: 
###################################################
bal.logit <- dx.wts(lalonde$w.logit,
                    data=lalonde,
                    vars=c("age","educ","black","hispan","nodegree","married","re74","re75"),
                    treat.var="treat",
                    perm.test.iters=0)
print(bal.logit)


###################################################
### chunk number 26: 
###################################################
pretty.tab <- bal.table(bal.logit)[[2]][,c("tx.mn","ct.mn","ks")]
pretty.tab <- cbind(pretty.tab, bal.table(bal.logit)[[1]]$ct.mn)
names(pretty.tab) <- c("E(Y1|t=1)","E(Y0|t=1)","KS","E(Y0|t=0)")
xtable(pretty.tab,
       caption = "Logistic regression estimates of the propensity scores",
       label = "tab:balancelogit",
       digits = c(0, 2, 2, 2, 2),
       align=c("l","r","r","r","r"))


###################################################
### chunk number 27: 
###################################################
bal.gbm <- dx.wts(ps.lalonde,
                  data=lalonde,
                  vars=c("age","educ","black","hispan","nodegree","married","re74","re75"),
                  treat.var="treat",
                  perm.test.iters=0)
pretty.tab <- rbind(bal.logit$summary.tab,
                    bal.gbm$summary.tab[-1,])
rownames(pretty.tab) <- pretty.tab$type
rownames(pretty.tab)[2] <- "logit"
pretty.tab <- pretty.tab[,c("n.treat","ess","max.es","mean.es","max.ks","mean.ks")]
xtable(pretty.tab,
       caption = "Summary of the balancing properties of logistic regression and gbm",
       label = "tab:balancecompare",
       digits = c(0, 0, 2, 2, 2, 2, 2),
       align=c("l","r","r","r","r","r","r"))


###################################################
### chunk number 28: 
###################################################
design.logit <- svydesign(ids=~1, weights=~w.logit, data=lalonde)
glm6 <- svyglm(re78 ~ treat, design=design.logit)
summary(glm6)


###################################################
### chunk number 29: 
###################################################
glm7 <- svyglm(re78 ~ treat + age + educ + black + hispan + nodegree +
                      married + re74 + re75,
               design=design.logit)


###################################################
### chunk number 30: 
###################################################
data(egsingle)


###################################################
### chunk number 31: 
###################################################
tmp <- sapply(split(egsingle,egsingle$childid),function(x){
              paste(as.character(x$grade),collapse="")})


###################################################
### chunk number 32: 
###################################################
tmp <- data.frame(childid=names(tmp), gpatt=tmp,
                  resp=as.numeric((1:length(tmp)) %in%
                          grep("1234",as.character(tmp))))


###################################################
### chunk number 33: 
###################################################
egsingle <- merge(egsingle, tmp)


###################################################
### chunk number 34: 
###################################################
egsingle.one <-unique(egsingle[,-c(3:6)])


###################################################
### chunk number 35: 
###################################################
egsingle.one$race <- as.factor(race <- ifelse(egsingle.one$black==1, 1,
                                         ifelse(egsingle.one$hispanic==1, 2, 3)))


###################################################
### chunk number 36: 
###################################################
egsingle.one$nresp <- 1-egsingle.one$resp


###################################################
### chunk number 37: psfig2
###################################################
par(mfrow=c(1,2))
egsingle.ps <-
   ps(nresp ~ race + female + size + lowinc + mobility,
      data=egsingle.one,
      plots="optimize",
      stop.method=stop.methods[c("es.stat.mean","ks.stat.max")],
      n.trees=2500,
      verbose=FALSE)


###################################################
### chunk number 38: 
###################################################
par(mfrow=c(1,2))
egsingle.ps <-
   ps(nresp ~ race + female + size + lowinc + mobility,
      data=egsingle.one,
      plots="optimize",
      stop.method=stop.methods[c("es.stat.mean","ks.stat.max")],
      n.trees=2500,
      verbose=FALSE)


###################################################
### chunk number 39: 
###################################################
pretty.tab<-bal.table(egsingle.ps)$ks.stat.max[,c("tx.mn","ct.mn","std.eff.sz","ks")]
names(pretty.tab) <- c("Non-responders","Weighted responders","Std ES","KS")
xtable(pretty.tab,
       caption = "Balance of the nonrespondents and respondents",
       label = "tab:balance2",
       digits = c(0, 2, 2, 2, 2),
       align=c("l","r","r","r","r"))


###################################################
### chunk number 40: 
###################################################
egsingle.one$wgt <- 1 + get.weights(egsingle.ps, type="ATT",
                                    stop.method="ks.stat.max")


###################################################
### chunk number 41: 
###################################################
 egsinge.resp <- merge(subset(egsingle, subset=resp==1),
                       subset(egsingle.one, subset=resp==1,
                              select=c(childid, wgt)) )


